@@ -4,13 +4,13 @@
 ###################################################
 ### code chunk number 1: TurtleGraphics.Rnw:56-57 (eval = FALSE)
 ###################################################
-## install_package("TurtleGraphics")
+## install.packages("TurtleGraphics")
 
 
 ###################################################
 ### code chunk number 2: TurtleGraphics.Rnw:62-63
 ###################################################
-require("TurtleGraphics")
+library("TurtleGraphics")
 
 
 ###################################################
@@ -66,7 +66,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 10: TurtleGraphics.Rnw:145-160
+### code chunk number 10: TurtleGraphics.Rnw:146-161
 ###################################################
 file <- paste("figure_3", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -86,13 +86,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 11: TurtleGraphics.Rnw:164-165
+### code chunk number 11: TurtleGraphics.Rnw:165-166
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 12: TurtleGraphics.Rnw:169-177 (eval = FALSE)
+### code chunk number 12: TurtleGraphics.Rnw:170-178 (eval = FALSE)
 ###################################################
 ## turtle_right(angle=90)
 ## turtle_forward(dist=10)
@@ -105,7 +105,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 13: TurtleGraphics.Rnw:192-214
+### code chunk number 13: TurtleGraphics.Rnw:193-215
 ###################################################
 file <- paste("figure_4", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -132,13 +132,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 14: TurtleGraphics.Rnw:218-219
+### code chunk number 14: TurtleGraphics.Rnw:219-220
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 15: TurtleGraphics.Rnw:223-231 (eval = FALSE)
+### code chunk number 15: TurtleGraphics.Rnw:224-232 (eval = FALSE)
 ###################################################
 ## turtle_right(90)
 ## turtle_up()
@@ -151,7 +151,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 16: TurtleGraphics.Rnw:241-268
+### code chunk number 16: TurtleGraphics.Rnw:242-269
 ###################################################
 file <- paste("figure_5", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -183,13 +183,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 17: TurtleGraphics.Rnw:272-273
+### code chunk number 17: TurtleGraphics.Rnw:273-274
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 18: TurtleGraphics.Rnw:277-281 (eval = FALSE)
+### code chunk number 18: TurtleGraphics.Rnw:278-282 (eval = FALSE)
 ###################################################
 ## turtle_hide()
 ## turtle_left(angle=150)
@@ -198,7 +198,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 19: TurtleGraphics.Rnw:292-321
+### code chunk number 19: TurtleGraphics.Rnw:293-322
 ###################################################
 file <- paste("figure_6", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -232,13 +232,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 20: TurtleGraphics.Rnw:325-326
+### code chunk number 20: TurtleGraphics.Rnw:326-327
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 21: TurtleGraphics.Rnw:330-333 (eval = FALSE)
+### code chunk number 21: TurtleGraphics.Rnw:331-334 (eval = FALSE)
 ###################################################
 ## turtle_col(col="green")
 ## turtle_left(angle=60)
@@ -246,7 +246,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 22: TurtleGraphics.Rnw:347-382
+### code chunk number 22: TurtleGraphics.Rnw:349-384
 ###################################################
 file <- paste("figure_7", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -286,13 +286,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 23: TurtleGraphics.Rnw:386-387
+### code chunk number 23: TurtleGraphics.Rnw:388-389
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 24: TurtleGraphics.Rnw:391-396 (eval = FALSE)
+### code chunk number 24: TurtleGraphics.Rnw:393-398 (eval = FALSE)
 ###################################################
 ## turtle_left(angle=150)
 ## turtle_lty(lty=4)
@@ -302,20 +302,20 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 25: TurtleGraphics.Rnw:407-408
+### code chunk number 25: TurtleGraphics.Rnw:411-412
 ###################################################
 turtle_status()
 
 
 ###################################################
-### code chunk number 26: TurtleGraphics.Rnw:414-416
+### code chunk number 26: TurtleGraphics.Rnw:418-420
 ###################################################
 turtle_getpos()
 turtle_getangle()
 
 
 ###################################################
-### code chunk number 27: TurtleGraphics.Rnw:427-465
+### code chunk number 27: TurtleGraphics.Rnw:431-469
 ###################################################
 file <- paste("figure_8", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -358,13 +358,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 28: TurtleGraphics.Rnw:469-470
+### code chunk number 28: TurtleGraphics.Rnw:473-474
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 29: TurtleGraphics.Rnw:474-478 (eval = FALSE)
+### code chunk number 29: TurtleGraphics.Rnw:478-482 (eval = FALSE)
 ###################################################
 ## turtle_reset()
 ## turtle_goto(x=10,y=50)
@@ -373,7 +373,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 30: TurtleGraphics.Rnw:488-495 (eval = FALSE)
+### code chunk number 30: TurtleGraphics.Rnw:494-501 (eval = FALSE)
 ###################################################
 ## turtle_init()
 ## turtle_do(expr = {
@@ -385,7 +385,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 31: TurtleGraphics.Rnw:498-508
+### code chunk number 31: TurtleGraphics.Rnw:504-514
 ###################################################
 file <- paste("figure_9", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -400,13 +400,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 32: TurtleGraphics.Rnw:512-513
+### code chunk number 32: TurtleGraphics.Rnw:518-519
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 33: TurtleGraphics.Rnw:550-563
+### code chunk number 33: TurtleGraphics.Rnw:556-569
 ###################################################
 file <- paste("figure_01", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -424,13 +424,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 34: TurtleGraphics.Rnw:567-568
+### code chunk number 34: TurtleGraphics.Rnw:573-574
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 35: TurtleGraphics.Rnw:572-582 (eval = FALSE)
+### code chunk number 35: TurtleGraphics.Rnw:578-588 (eval = FALSE)
 ###################################################
 ## turtle_init()
 ## turtle_up()
@@ -445,7 +445,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 36: TurtleGraphics.Rnw:597-604
+### code chunk number 36: TurtleGraphics.Rnw:603-610
 ###################################################
 file <- paste("figure_03", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -457,13 +457,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 37: TurtleGraphics.Rnw:608-609
+### code chunk number 37: TurtleGraphics.Rnw:614-615
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 38: TurtleGraphics.Rnw:613-621 (eval = FALSE)
+### code chunk number 38: TurtleGraphics.Rnw:619-627 (eval = FALSE)
 ###################################################
 ## turtle_init()
 ## turtle_forward(dist=10)
@@ -476,7 +476,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 39: TurtleGraphics.Rnw:630-645
+### code chunk number 39: TurtleGraphics.Rnw:635-650
 ###################################################
 file <- paste("figure_04", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -496,13 +496,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 40: TurtleGraphics.Rnw:649-650
+### code chunk number 40: TurtleGraphics.Rnw:654-655
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 41: TurtleGraphics.Rnw:654-666 (eval = FALSE)
+### code chunk number 41: TurtleGraphics.Rnw:659-671 (eval = FALSE)
 ###################################################
 ## turtle_init()
 ## turtle_forward(dist=10)
@@ -519,7 +519,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 42: TurtleGraphics.Rnw:678-684 (eval = FALSE)
+### code chunk number 42: TurtleGraphics.Rnw:683-689 (eval = FALSE)
 ###################################################
 ## turtle_square <- function(r){
 ##    for(i in 1:4){
@@ -530,7 +530,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 43: TurtleGraphics.Rnw:692-706
+### code chunk number 43: TurtleGraphics.Rnw:697-711
 ###################################################
 file <- paste("figure_02", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -549,13 +549,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 44: TurtleGraphics.Rnw:710-711
+### code chunk number 44: TurtleGraphics.Rnw:715-716
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 45: TurtleGraphics.Rnw:714-719 (eval = FALSE)
+### code chunk number 45: TurtleGraphics.Rnw:719-724 (eval = FALSE)
 ###################################################
 ## turtle_init()
 ## turtle_square()
@@ -565,7 +565,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 46: TurtleGraphics.Rnw:761-770
+### code chunk number 46: TurtleGraphics.Rnw:766-775
 ###################################################
 file <- paste("figure_10", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -579,13 +579,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 47: TurtleGraphics.Rnw:774-775
+### code chunk number 47: TurtleGraphics.Rnw:779-780
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 48: TurtleGraphics.Rnw:779-784 (eval = FALSE)
+### code chunk number 48: TurtleGraphics.Rnw:784-789 (eval = FALSE)
 ###################################################
 ## turtle_init(100, 100, mode = "cycle")
 ## for(i in 1:10){
@@ -595,7 +595,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 49: TurtleGraphics.Rnw:790-810
+### code chunk number 49: TurtleGraphics.Rnw:795-815
 ###################################################
 file <- paste("figure_11", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -620,13 +620,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 50: TurtleGraphics.Rnw:814-815
+### code chunk number 50: TurtleGraphics.Rnw:819-820
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 51: TurtleGraphics.Rnw:819-836 (eval = FALSE)
+### code chunk number 51: TurtleGraphics.Rnw:824-841 (eval = FALSE)
 ###################################################
 ## drawSpiral <- function(lineLen){
 ##    if (lineLen > 0){
@@ -648,7 +648,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 52: TurtleGraphics.Rnw:841-865
+### code chunk number 52: TurtleGraphics.Rnw:846-870
 ###################################################
 file <- paste("figure_15", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -677,13 +677,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 53: TurtleGraphics.Rnw:869-870
+### code chunk number 53: TurtleGraphics.Rnw:874-875
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 54: TurtleGraphics.Rnw:874-893 (eval = FALSE)
+### code chunk number 54: TurtleGraphics.Rnw:879-898 (eval = FALSE)
 ###################################################
 ## turtle_star <- function(intensity=1){
 ##    y <- sample(1:657, 360*intensity, replace=TRUE)
@@ -707,7 +707,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 55: TurtleGraphics.Rnw:900-917
+### code chunk number 55: TurtleGraphics.Rnw:905-922
 ###################################################
 file <- paste("figure_16", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -729,13 +729,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 56: TurtleGraphics.Rnw:921-922
+### code chunk number 56: TurtleGraphics.Rnw:926-927
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 57: TurtleGraphics.Rnw:927-939 (eval = FALSE)
+### code chunk number 57: TurtleGraphics.Rnw:932-944 (eval = FALSE)
 ###################################################
 ## turtle_brownian <- function(steps=100, length=10){
 ##    turtle_lwd(2)
@@ -752,7 +752,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 58: TurtleGraphics.Rnw:945-983
+### code chunk number 58: TurtleGraphics.Rnw:950-988
 ###################################################
 file <- paste("figure_12", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -795,13 +795,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 59: TurtleGraphics.Rnw:987-988
+### code chunk number 59: TurtleGraphics.Rnw:992-993
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 60: TurtleGraphics.Rnw:993-1024 (eval = FALSE)
+### code chunk number 60: TurtleGraphics.Rnw:998-1029 (eval = FALSE)
 ###################################################
 ## fractal_tree <- function(s=100, n=2) {
 ##    if (n <= 1) {
@@ -837,7 +837,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 61: TurtleGraphics.Rnw:1030-1059
+### code chunk number 61: TurtleGraphics.Rnw:1035-1064
 ###################################################
 file <- paste("figure_13", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -871,13 +871,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 62: TurtleGraphics.Rnw:1063-1064
+### code chunk number 62: TurtleGraphics.Rnw:1068-1069
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 63: TurtleGraphics.Rnw:1068-1093 (eval = FALSE)
+### code chunk number 63: TurtleGraphics.Rnw:1073-1098 (eval = FALSE)
 ###################################################
 ## turtle_init(600, 400, "error")
 ## turtle_up()
@@ -907,7 +907,7 @@ cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 64: TurtleGraphics.Rnw:1099-1134
+### code chunk number 64: TurtleGraphics.Rnw:1104-1139
 ###################################################
 file <- paste("figure_14", ".pdf", sep="")
 pdf(file=file, onefile=FALSE)
@@ -947,13 +947,13 @@ dev.off()
 
 
 ###################################################
-### code chunk number 65: TurtleGraphics.Rnw:1138-1139
+### code chunk number 65: TurtleGraphics.Rnw:1143-1144
 ###################################################
 cat("\\includegraphics[width=10cm]{", file, "}\n\n", sep="")
 
 
 ###################################################
-### code chunk number 66: TurtleGraphics.Rnw:1143-1174 (eval = FALSE)
+### code chunk number 66: TurtleGraphics.Rnw:1148-1179 (eval = FALSE)
 ###################################################
 ## drawTriangle<- function(points){
 ##    turtle_setpos(points[1,1],points[1,2])
